ekiga r7061 - in trunk: . lib/engine/addressbook/call-history lib/engine/addressbook/evolution lib/engine/addressbook/kab lib/engine/addressbook/ldap lib/engine/addressbook/skel lib/engine/gui/gtk-frontend lib/gui



Author: jpuydt
Date: Tue Sep 23 05:51:52 2008
New Revision: 7061
URL: http://svn.gnome.org/viewvc/ekiga?rev=7061&view=rev

Log:
Fixed #553143.

Modified:
   trunk/ChangeLog
   trunk/lib/engine/addressbook/call-history/history-book.cpp
   trunk/lib/engine/addressbook/call-history/history-book.h
   trunk/lib/engine/addressbook/evolution/evolution-book.cpp
   trunk/lib/engine/addressbook/evolution/evolution-book.h
   trunk/lib/engine/addressbook/kab/kab-book.h
   trunk/lib/engine/addressbook/ldap/ldap-book.cpp
   trunk/lib/engine/addressbook/ldap/ldap-book.h
   trunk/lib/engine/addressbook/skel/book.h
   trunk/lib/engine/gui/gtk-frontend/addressbook-window.cpp
   trunk/lib/gui/gmstockicons.c
   trunk/lib/gui/gmstockicons.h

Modified: trunk/lib/engine/addressbook/call-history/history-book.cpp
==============================================================================
--- trunk/lib/engine/addressbook/call-history/history-book.cpp	(original)
+++ trunk/lib/engine/addressbook/call-history/history-book.cpp	Tue Sep 23 05:51:52 2008
@@ -164,12 +164,6 @@
   return ""; // nothing special here
 }
 
-const std::string
-History::Book::get_type () const
-{
-  return "history"; 
-}
-
 void
 History::Book::set_search_filter (std::string /*filter*/)
 {

Modified: trunk/lib/engine/addressbook/call-history/history-book.h
==============================================================================
--- trunk/lib/engine/addressbook/call-history/history-book.h	(original)
+++ trunk/lib/engine/addressbook/call-history/history-book.h	Tue Sep 23 05:51:52 2008
@@ -71,7 +71,8 @@
 
     const std::string get_status () const;
 
-    const std::string get_type () const;
+    const std::string get_icon () const
+    { return "local-object"; }
 
     void set_search_filter (std::string);
 

Modified: trunk/lib/engine/addressbook/evolution/evolution-book.cpp
==============================================================================
--- trunk/lib/engine/addressbook/evolution/evolution-book.cpp	(original)
+++ trunk/lib/engine/addressbook/evolution/evolution-book.cpp	Tue Sep 23 05:51:52 2008
@@ -260,12 +260,6 @@
   return status;
 }
 
-const std::string
-Evolution::Book::get_type () const
-{
-  return "local";
-}
-
 void
 Evolution::Book::refresh ()
 {

Modified: trunk/lib/engine/addressbook/evolution/evolution-book.h
==============================================================================
--- trunk/lib/engine/addressbook/evolution/evolution-book.h	(original)
+++ trunk/lib/engine/addressbook/evolution/evolution-book.h	Tue Sep 23 05:51:52 2008
@@ -74,7 +74,8 @@
 
     const std::string get_status () const;
 
-    const std::string get_type () const;
+    const std::string get_icon () const
+    { return "local-object"; }
 
     void refresh ();
 

Modified: trunk/lib/engine/addressbook/kab/kab-book.h
==============================================================================
--- trunk/lib/engine/addressbook/kab/kab-book.h	(original)
+++ trunk/lib/engine/addressbook/kab/kab-book.h	Tue Sep 23 05:51:52 2008
@@ -67,8 +67,8 @@
     const std::string get_status () const
     { return "---"; }
 
-    const std::string get_type () const
-    { return "FIXME"; }
+    const std::string get_icon () const
+    { return "local-object"; }
 
     void set_search_filter (std::string)
     {}

Modified: trunk/lib/engine/addressbook/ldap/ldap-book.cpp
==============================================================================
--- trunk/lib/engine/addressbook/ldap/ldap-book.cpp	(original)
+++ trunk/lib/engine/addressbook/ldap/ldap-book.cpp	Tue Sep 23 05:51:52 2008
@@ -331,12 +331,6 @@
   return status;
 }
 
-const std::string
-OPENLDAP::Book::get_type () const
-{
-  return "remote";
-}
-
 
 void
 OPENLDAP::Book::refresh ()

Modified: trunk/lib/engine/addressbook/ldap/ldap-book.h
==============================================================================
--- trunk/lib/engine/addressbook/ldap/ldap-book.h	(original)
+++ trunk/lib/engine/addressbook/ldap/ldap-book.h	Tue Sep 23 05:51:52 2008
@@ -83,7 +83,8 @@
 
     const std::string get_status () const;
 
-    const std::string get_type () const;
+    const std::string get_icon () const
+    { return "remote-object"; }
 
     void refresh ();
 

Modified: trunk/lib/engine/addressbook/skel/book.h
==============================================================================
--- trunk/lib/engine/gui/gtk-frontend/addressbook-window.cpp	(original)
+++ trunk/lib/engine/gui/gtk-frontend/addressbook-window.cpp	Tue Sep 23 05:51:52 2008
@@ -439,12 +439,9 @@
 
   g_signal_connect (view, "updated", G_CALLBACK (on_view_updated), self);
 
-  if (book.get_type () == "remote")
-    icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view), 
-                                   GM_STOCK_REMOTE_CONTACT, GTK_ICON_SIZE_MENU, NULL); 
-  else
-    icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view), 
-                                   GM_STOCK_LOCAL_CONTACT, GTK_ICON_SIZE_MENU, NULL); 
+  icon = gtk_widget_render_icon (GTK_WIDGET (self->priv->tree_view),
+				 book.get_icon ().c_str (),
+				 GTK_ICON_SIZE_MENU, NULL); 
 
   store = gtk_tree_view_get_model (GTK_TREE_VIEW (self->priv->tree_view));
   gtk_tree_store_append (GTK_TREE_STORE (store), &iter, NULL);

Modified: trunk/lib/gui/gmstockicons.c
==============================================================================
--- trunk/lib/gui/gmstockicons.c	(original)
+++ trunk/lib/gui/gmstockicons.c	Tue Sep 23 05:51:52 2008
@@ -71,8 +71,8 @@
 		{ GM_STOCK_STATUS_DND, gm_status_dnd_stock_data },
 		{ GM_STOCK_STATUS_INACALL, gm_status_inacall_stock_data_16 },
 
-		{ GM_STOCK_REMOTE_CONTACT, gm_remote_contact_stock_data},
-		{ GM_STOCK_LOCAL_CONTACT, gm_local_contact_stock_data},
+		{ GM_STOCK_REMOTE_OBJECT, gm_remote_contact_stock_data},
+		{ GM_STOCK_LOCAL_OBJECT, gm_local_contact_stock_data},
 		{ GM_STOCK_MESSAGE, gm_message_stock_data},
 		{ GM_STOCK_CALL_PLACED, gm_call_placed_stock_data},
 		{ GM_STOCK_CALL_MISSED, gm_call_missed_stock_data},

Modified: trunk/lib/gui/gmstockicons.h
==============================================================================
--- trunk/lib/gui/gmstockicons.h	(original)
+++ trunk/lib/gui/gmstockicons.h	Tue Sep 23 05:51:52 2008
@@ -58,8 +58,8 @@
 #define GM_STOCK_COLOR_BRIGHTNESS_CONTRAST   "gm_color_brightness_contrast_stock"
 #define GM_STOCK_STATUS_FREEFORCHAT "gm_status_freeforchat_stock"
 #define GM_STOCK_STATUS_RINGING "gm_status_ringing_stock"
-#define GM_STOCK_LOCAL_CONTACT    "gm_local_contact_stock"
-#define GM_STOCK_REMOTE_CONTACT   "gm_remote_contact_stock"
+#define GM_STOCK_LOCAL_OBJECT    "local-object"
+#define GM_STOCK_REMOTE_OBJECT   "remote-object"
 #define GM_STOCK_MESSAGE          "gm_message_stock"
 #define GM_STOCK_CALL_PLACED      "gm_call_placed_stock"
 #define GM_STOCK_CALL_MISSED      "gm_call_missed_stock"



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/lib/engine/addressbook/skel/book.h	(original)
+++ trunk/lib/engine/addressbook/skel/book.h	Tue Sep 23 05:51:52 2008
@@ -91,15 +91,15 @@
     virtual const std::string get_status () const = 0;
 
     
     /** Get the type of the Book.
      * The type is a string and could be something like 'local' or
      * 'remote'. 
      *
      * This function is purely virtual and should be implemented by
      * the descendant of the Ekiga::Book, ie BookImpl or one
      * of its descendant.
      */
-    virtual const std::string get_type () const = 0;
+    virtual const std::string get_icon () const = 0;
 
 
     /*
@@ -91,15 +91,15 @@
 
     
-    /** Get the type of the Book.
-     * The type is a string and could be something like 'local' or
-     * 'remote'. 
+    /** Get the icon for the Book.
+     * The icon is a string and could be something like "local-object"
+     * or "remote-object"
      *
      * This function is purely virtual and should be implemented by

Modified: trunk/lib/engine/gui/gtk-frontend/addressbook-window.cpp
==============================================================================